Returns a closure computing the probability density function of the asymptotic normal (univariate) or multivariate normal (multivariate) distribution of the MLE.
Usage
# S3 method for class 'mle'
density(x, ...)Returns a closure computing the probability density function of the asymptotic normal (univariate) or multivariate normal (multivariate) distribution of the MLE.
# S3 method for class 'mle'
density(x, ...)