Returns the parameter estimates, which are the mean of the asymptotic distribution.
Usage
# S3 method for class 'mle'
mean(x, ...)Returns the parameter estimates, which are the mean of the asymptotic distribution.
# S3 method for class 'mle'
mean(x, ...)