Function for obtaining an estimate of the standard error of the MLE object `x`.
Source:R/mle.R
se.mle.RdFunction for obtaining an estimate of the standard error of the MLE object `x`.
Usage
# S3 method for class 'mle'
se(x, se.matrix = FALSE, ...)