Function to compute the confidence intervals from a variance-covariance matrix
Source:R/utils.R
confint_from_sigma.RdFunction to compute the confidence intervals from a variance-covariance matrix
Value
Matrix of confidence intervals with rows for each parameter and columns for lower and upper bounds.
Examples
# Compute CI for a bivariate parameter
theta <- c(mu = 5.2, sigma2 = 4.1)
vcov_matrix <- diag(c(0.1, 0.5)) # Variance of estimators
confint_from_sigma(vcov_matrix, theta)
#> 2.5% 97.5%
#> mu 4.580205 5.819795
#> sigma2 2.714096 5.485904
confint_from_sigma(vcov_matrix, theta, level = 0.99)
#> 0.5% 99.5%
#> mu 4.385451 6.014549
#> sigma2 2.278614 5.921386